==> flexistyle_bootstrap-1.0.0.tar.gz: flexistyle_bootstrap/README.md <==
## Table of contents

- Introduction
- Requirements
- Installation
- Configuration
- Create subtheme
- Maintainers


## Introduction

FlexiStyle Bootstrap is based on the FlexiStyle Drupal
base theme. This theme is fully compatible with Drupal 10.
It is a dynamic and modern custom theme designed
specifically for Drupal. Its theme completely overwrites
standard root twig templates. This theme is based on
bootstrap based layout and structure. This theme seamlessly
integrates aesthetics with functionality, offering a
visually striking and user-friendly.

This theme supports all the bootstrap versions. It is a
lightweight theme because we are attaching all the CSS and
JS libraries based on the components and disabling
unnecessary libraries. theme performance, best practices,
and SEO scores are high in a lighthouse.

The theme is fully responsive and mobile-first. Use the
latest version of Fontawesome and Google material libraries
for icons in this theme. All the sections, colors, sizes,
widths, columns and containers are fully based on the
bootstrap.

"Flexi Style Bootstrap" theme settings are manageable, You
can change the header, navbar, footer, Bootstrap version,
and maintenance mode time settings and styles from the theme
appearance. This theme is fully supportable with the
Progressive web application (PWA).


## Requirements

This theme requires Drupal core `>= 9.0`.
This theme does not require any theme and modules outside of Drupal core.


## Installation

Install as you would normally install a contributed Drupal theme.
Install with composer `composer require 'drupal/flexistyle_bootstrap'`
then enable the theme.


## Configuration

Go to the **Administration** » Appearance.
On the same page "FlexiStyle Bootstrap" theme and click on the install and set as default.


## Create subtheme

1. You can create a subtheme through a shell script.
2. Install the **"FlexiStyle Bootstrap"** theme with the composer `composer require 'drupal/flexistyle_bootstrap` but don't enable it.
3. Go to the theme folder from shell or command prompt: `cd themes/contrib/flexistyle_bootstrap`.
4. Run this command from the shell "Make script executable": `chmod +x scripts/subtheme.sh`.
5. Run this command from the shell to launch the script: `sh scripts/subtheme.sh` or `./scripts/subtheme.sh`.
6. That script will ask the questions for you to create your subtheme.
	1. Type machine_name of the theme: **my_theme**
	2. Type Name of the theme: **My Theme**
7. Go to the administration -> Appearance and enable the `my_theme`.


## Maintainers

- Anoop Singh - [anoopsingh92](https://www.drupal.org/u/anoopsingh92)

==> flexistyle_bootstrap-1.0.1.tar.gz: flexistyle_bootstrap/README.md <==
## Table of contents

- Introduction
- Requirements
- Installation
- Configuration
- Create subtheme
- Maintainers


## Introduction

FlexiStyle Bootstrap is based on the FlexiStyle Drupal
base theme. This theme is fully compatible with Drupal 10.
It is a dynamic and modern custom theme designed
specifically for Drupal. Its theme completely overwrites
standard root twig templates. This theme is based on
bootstrap based layout and structure. This theme seamlessly
integrates aesthetics with functionality, offering a
visually striking and user-friendly.

This theme supports all the bootstrap versions. It is a
lightweight theme because we are attaching all the CSS and
JS libraries based on the components and disabling
unnecessary libraries. theme performance, best practices,
and SEO scores are high in a lighthouse.

The theme is fully responsive and mobile-first. Use the
latest version of Fontawesome and Google material libraries
for icons in this theme. All the sections, colors, sizes,
widths, columns and containers are fully based on the
bootstrap.

"Flexi Style Bootstrap" theme settings are manageable, You
can change the header, navbar, footer, Bootstrap version,
and maintenance mode time settings and styles from the theme
appearance. This theme is fully supportable with the
Progressive web application (PWA).


## Requirements

This theme requires Drupal core `>= 9.0`.
This theme does not require any theme and modules outside of Drupal core.


## Installation

Install as you would normally install a contributed Drupal theme.
Install with composer `composer require 'drupal/flexistyle_bootstrap'`
then enable the theme.


## Configuration

Go to the **Administration** » Appearance.
On the same page "FlexiStyle Bootstrap" theme and click on
the install and set as default.


## Create subtheme

1. You can create a subtheme through a shell script.
2. Install the **"FlexiStyle Bootstrap"** theme with the composer
   `composer require 'drupal/flexistyle_bootstrap` but don't enable it.
3. Go to the theme folder from shell or command
   prompt: `cd themes/contrib/flexistyle_bootstrap`.
4. Run this command from the shell "Make script
   executable": `chmod +x scripts/subtheme.sh`.
5. Run this command from the shell to launch the
   script: `sh scripts/subtheme.sh` or `./scripts/subtheme.sh`.
6. That script will ask the questions for you to create your subtheme.
	1. Type machine_name of the theme: **my_theme**
	2. Type Name of the theme: **My Theme**
7. Go to the administration -> Appearance and enable the `my_theme`.


## Maintainers

- Anoop Singh - [anoopsingh92](https://www.drupal.org/u/anoopsingh92)
